# megadata

lib and tools for 'megadata'

# install

python -m pip install -U megadata

# TODO

## client shell for different databases/server ;)
* python -m megadata *args **kwargs

## TODO scheme myipc:// ?
